summaryrefslogtreecommitdiffstats
path: root/src/mechanics/mechanicsitem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /src/mechanics/mechanicsitem.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/mechanics/mechanicsitem.h')
-rw-r--r--src/mechanics/mechanicsitem.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/src/mechanics/mechanicsitem.h b/src/mechanics/mechanicsitem.h
index db500fc..8c73d9d 100644
--- a/src/mechanics/mechanicsitem.h
+++ b/src/mechanics/mechanicsitem.h
@@ -12,13 +12,13 @@
#define MECHANICSITEM_H
#include <item.h>
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
class LibraryItem;
class MechanicsItem;
// class MechanicsItemOverlayItem;
class MechanicsDocument;
-typedef QValueList<MechanicsItem*> MechanicsItemList;
+typedef TQValueList<MechanicsItem*> MechanicsItemList;
/**
@short Stores mass, moment of inertia
@@ -118,8 +118,9 @@ protected:
class MechanicsItem : public Item
{
Q_OBJECT
+ TQ_OBJECT
public:
- MechanicsItem( MechanicsDocument *mechanicsDocument, bool newItem, const QString &id );
+ MechanicsItem( MechanicsDocument *mechanicsDocument, bool newItem, const TQString &id );
virtual ~MechanicsItem();
enum SelectionMode
@@ -151,18 +152,18 @@ public:
*/
PositionInfo absolutePosition() const;
/**
* Returns the position relative to the parent item (or the absolute
* position if there is no parent item)
*/
PositionInfo relativePosition() const { return m_relativePosition; }
/**
* Returns the mechanics info for this item (so not taking into account that
- * of attached children)
+ * of attached tqchildren)
*/
MechanicsInfo *mechanicsInfo() { return &m_mechanicsInfo; }
/**
* Returns the combined mechanics info for this item (which takes into
- * account that of attached children).
+ * account that of attached tqchildren).
*/
CombinedMechanicsInfo *mechanicsInfoCombined() { return &m_mechanicsInfoCombined; }
/**
@@ -170,7 +171,7 @@ public:
* rectangle, given this items current rotation. Legitimately means that
* whether this item is allowed to be distorted, inverted, resized, etc.
*/
- QRect maxInnerRectangle( const QRect &outerRect ) const;
+ TQRect maxInnerRectangle( const TQRect &outerRect ) const;
virtual ItemData itemData() const;
@@ -187,7 +188,7 @@ public slots:
* Rotate the item by the given amount (in radians)
*/
void rotateBy( double dtheta );
- void parentMoved();
+ void tqparentMoved();
signals:
/**
@@ -212,11 +213,11 @@ protected:
/**
* Sets the correct orientation on the painter
*/
- void initPainter( QPainter &p );
+ void initPainter( TQPainter &p );
/**
* *Must* be called after calling initPainter, if initPainter was called
*/
- void deinitPainter( QPainter &p );
+ void deinitPainter( TQPainter &p );
virtual void dataChanged();
virtual void itemPointsChanged() { updateCanvasPoints(); }
/**
@@ -226,7 +227,7 @@ protected:
void updateCanvasPoints();
MechanicsDocument *p_mechanicsDocument;
- PositionInfo m_relativePosition; // Absolution position if not attached to a parent item, or otherwise relative to parent item
+ PositionInfo m_relativePosition; // Absolution position if not attached to a tqparent item, or otherwise relative to tqparent item
MechanicsInfo m_mechanicsInfo;
CombinedMechanicsInfo m_mechanicsInfoCombined;
@@ -151,18 +152,18 @@ public:
PositionInfo absolutePosition() const;
/**
- * Returns the position relative to the parent item (or the absolute
- * position if there is no parent item)
+ * Returns the position relative to the tqparent item (or the absolute
+ * position if there is no tqparent item)
*/
PositionInfo relativePosition() const { return m_relativePosition; }